# nextrpg

Build your next RPG (Role Playing Game).

## Installation

```bash
pip install nextrpg
```
## Example

Work in progress.

## Features

Work in progress.

## License

This project is licensed under the MIT License - see the LICENSE file for details. 